pub type InstaPoolHistoryRecordOf<T> = InstaPoolHistoryRecord<BalanceOf<T>>;Aliased Type
struct InstaPoolHistoryRecordOf<T> {
pub private_contributions: u32,
pub system_contributions: u32,
pub maybe_payout: Option<<<T as Config>::Currency as Inspect<<T as Config>::AccountId>>::Balance>,
}Fields
private_contributions: u32The total amount of Coretime (measured in Core Mask Bits minus any contributions which have already been paid out.
system_contributions: u32The total amount of Coretime (measured in Core Mask Bits contributed by the Polkadot System in this timeslice.
maybe_payout: Option<<<T as Config>::Currency as Inspect<<T as Config>::AccountId>>::Balance>The payout remaining for the private_contributions, or None if the revenue is not yet
known.